==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/core.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'accept'=>'Akzeptieren',
'access_denied'=>'Zugriff verweigert',
'action_has_not_committed_transaction'=>'Prozeß wegen offener Transaktion abgebrochen!',
'all'=>'alle',
'allow'=>'Erlauben',
'all_times_are'=>'Alle Zeitangaben sind',
'an_error_occured'=>'Ein Fehler ist aufgetreten',
'ap_exec'=>'Verwalter',
'ap_mod'=>'Moderatoren',
'ap_owner'=>'Eigentümer',
'ascending'=>'Aufsteigend',
'back_to_topic'=>'Zurück zum Thema',
'be_careful_on_external_content'=>'Sei vorsichtig mit fremden Inhalten!',
'by'=>'von',
'clear'=>'Leeren',
'click_here_for_redirection'=>'Bitte klicke hier, falls du nicht automatisch weitergeleitet wirst...',
'create_new_user_account'=>'Neuen Benutzer anlegen',
'currently_none'=>'zur Zeit keine',
'date'=>'Datum',
'day'=>'Tag',
'days'=>'Tage',
'default'=>'standard',
'delete'=>'Löschen',
'deny'=>'Verweigern',
'descending'=>'Absteigend',
'disable'=>'Deaktivieren',
'edit'=>'Ändern',
'enable'=>'Aktivieren',
'executive_panel'=>'Verwalter-Konsole',
'expired'=>'abgelaufen',
'explain_error_message'=>'Üblicherweise erhälst du diesen Fehler, weil du nicht mit deinem Benutzerkonto angemeldet bist. Ein anderer Grund wäre eine ungültig gewordene Zugriffserlaubnis. Dann solltest du diese Seite im Browser neu laden und das Forum fragt dich nach einer Neuaustellung. Zu guter letzt ist es schlicht möglich, daß du keine Rechte hast, diesen Bereich zu betreten.',
'fail'=>'Fehlgeschlagen',
'file_not_found'=>'Datei nicht gefunden',
'fun_message_1'=>'Du hast das "Zauberwort" vergessen...',
'fun_message_2'=>'Ich denke, daß ich genug von dir habe...',
'fun_message_3'=>'Siehst du nicht, ich bin beschäftigt?',
'fun_message_4'=>'Ich bitte um Entschuldigung?',
'fun_message_5'=>'Nein, das mache ich nicht!',
'fun_message_6'=>'The same procedure as every year, James!',
'fun_message_7'=>'Störe mich jetzt nicht, du *"\$/(=!',
'fun_message_8'=>'*seufz*',
'go_one_step_back'=>'Klicke hier, wenn du einen Schritt zurück möchtest...',
'group'=>'Benutzergruppe',
'group_alias_exec'=>'Verwalter',
'group_alias_guest'=>'Unangemeldet',
'group_alias_mod'=>'Moderator',
'group_alias_root'=>'Super-Benutzer',
'group_alias_user'=>'Mitglied',
'guest'=>'Gast',
'help'=>'Hilfe',
'hidden'=>'Versteckt',
'home'=>'Startseite',
'hour'=>'Stunde',
'hours'=>'Stunden',
'imprint_and_privacy'=>'Impressum und Datenschutzerklärung',
'invalid_form_input'=>'Bitte überprüfe deine Angaben, da einige abgelehnt wurden!',
'javascript_hint'=>'Bitte aktiviere <em>Javascript</em> in deinem Browser, um volle Funktionalität des Forums zu erlangen! Du kannst die Grundfunktionen aber ohne benutzen, sofern du Sicherheitsbedenken hast. Um es zu aktivieren, siehe bitte in der Browserhilfe nach wie man das bewerkstelligt. Üblicherweise ist es unter "Optionen" oder "Einstellungen" zu finden.',
'last_reply'=>'Letzte Antwort',
'login'=>'Anmelden',
'login_valid_for'=>'Verbleibende Anmeldezeit',
'logout'=>'Abmelden',
'mail_address'=>'E-Mail Adresse',
'member_list'=>'Mitgliederliste',
'message'=>'Nachricht',
'minute'=>'Minute',
'minutes'=>'Minuten',
'moderation_panel'=>'Moderation-Konsole',
'month'=>'Monat',
'must_not_alter_foreign_entry'=>'Es ist dir nicht erlaubt fremde Daten zu bearbeiten!',
'my_profile'=>'Mein Profil',
'name'=>'Name',
'new'=>'Neu',
'no'=>'nein',
'none'=>'keine',
'no_members_found'=>'Keine Mitglieder entsprechen deiner Anfrage...',
'no_valid_id'=>'Deine ausgewählte ID ist ungültig!',
'on'=>'am',
'options'=>'Optionen',
'order_by'=>'Sortierung',
'overview'=>'Übersicht',
'page'=>'Seite',
'password'=>'Kennwort',
'pending_requests'=>'Aktuell ausstehende Anfragen',
'please_confirm_reverting'=>'Bitte bestätige, daß du wirklich auf diese Revision rücksetzen möchtest?',
'please_confirm_your_selection'=>'Bitte bestätige, daß du die ausgewählten Objekte unwiederbringlich löschen willst?',
'post_count'=>'Beiträge',
'post_count_hint'=>'Dieser Wert ist ein Schuß ins Blaue und mag von der Wirklichkeit abweichen.',
'prefix_announcement'=>'Ankündigung',
'prefix_executive_only'=>'Nur für Verwalter',
'prefix_moderator_only'=>'Nur für Moderatoren',
'prefix_staff_only'=>'Nur für den Stab',
'prefix_support_request'=>'Benötige Hilfe',
'preview'=>'Vorschau',
'profile_view'=>'Profilansicht',
'query_for'=>'Suche Mitglieder',
'rating'=>'Bewertung',
'really_logout'=>'Möchtest du dich wirklich abmelden?',
'redirection'=>'Weiterleitung',
'register'=>'Registrieren',
'registration_date'=>'Registriert seit',
'replies'=>'Antworten',
'requires_elevated_permissions'=>'Du must in einer Benutzergruppe sein, die erhöhte Rechte besitzt (Verwalter/Moderator), um dies zu tun.',
'running_action_denied_by_acl'=>'Du bist nicht befugt diese Aktion auszuführen, da du von der Zugriffsregel abgewiesen wurdest',
'search'=>'Suche',
'search_posts_by_user'=>'Suche Beiträge',
'second'=>'Sekunde',
'seconds'=>'Sekunden',
'select_user'=>'Benutzer auswählen',
'sort_by'=>'Sortiere nach',
'stage'=>'Was tun?',
'standard_panel'=>'Benutzer-Konsole',
'subject'=>'Betreff',
'submit'=>'Absenden',
'success'=>'Erfolgreich',
'tags'=>'Stichwörter',
'to'=>'bis',
'today'=>'Heute',
'total'=>'Total',
'transaction_number_invalid'=>'Du hast nicht die korrekte Transaktionsnummer angegeben!',
'user'=>'Benutzer',
'username'=>'Benutzername',
'user_request'=>'Benutzer-Anfrage',
'visible'=>'Sichtbar',
'warning_high'=>'Du hast unsere Regeln mehrmals verletzt und die höchste Warnstufe erreicht!',
'warning_level'=>'Warnstufe',
'warning_level_high'=>'Hat schon eine Menge Ärger durch Regelverstöße gemacht',
'warning_level_low'=>'Wurde einmalig gewarnt',
'warning_level_medium'=>'Benötigt Aufmerksamkeit auf weiteres Fehlverhalten',
'warning_level_none'=>'Bis jetzt keine Warnung ausgesprochen',
'welcome'=>'Willkommen',
'year'=>'Jahr',
'yes'=>'ja',
'yesterday'=>'Gestern'
);
?>

==> larus_board-0.9.16.zip: larus_board-0.9.16/lb_private/lang/de/core.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'accept'=>'Akzeptieren',
'access_denied'=>'Zugriff verweigert',
'action_has_not_committed_transaction'=>'Prozeß wegen offener Transaktion abgebrochen!',
'all'=>'alle',
'allow'=>'Erlauben',
'all_times_are'=>'Alle Zeitangaben sind',
'an_error_occured'=>'Ein Fehler ist aufgetreten',
'ap_exec'=>'Verwalter',
'ap_mod'=>'Moderatoren',
'ap_owner'=>'Eigentümer',
'ascending'=>'Aufsteigend',
'back_to_topic'=>'Zurück zum Thema',
'be_careful_on_external_content'=>'Sei vorsichtig mit fremden Inhalten!',
'by'=>'von',
'clear'=>'Leeren',
'click_here_for_redirection'=>'Bitte klicke hier, falls du nicht automatisch weitergeleitet wirst...',
'create_new_user_account'=>'Neuen Benutzer anlegen',
'currently_none'=>'zur Zeit keine',
'date'=>'Datum',
'day'=>'Tag',
'days'=>'Tage',
'default'=>'standard',
'delete'=>'Löschen',
'delete_not_confirmed'=>'Du hast das Löschen nicht bestätigt.',
'deny'=>'Verweigern',
'descending'=>'Absteigend',
'disable'=>'Deaktivieren',
'edit'=>'Ändern',
'embed_object_flash'=>'Flash-Film',
'embed_object_unknown'=>'Unbekannt',
'embed_object_vector'=>'Vektorgrafik',
'enable'=>'Aktivieren',
'executive_panel'=>'Verwalter-Konsole',
'expired'=>'abgelaufen',
'explain_error_message'=>'Üblicherweise erhälst du diesen Fehler, weil du nicht mit deinem Benutzerkonto angemeldet bist. Ein anderer Grund wäre eine ungültig gewordene Zugriffserlaubnis. Dann solltest du diese Seite im Browser neu laden und das Forum fragt dich nach einer Neuaustellung. Zu guter letzt ist es schlicht möglich, daß du keine Rechte hast, diesen Bereich zu betreten.',
'fail'=>'Fehlgeschlagen',
'file_not_found'=>'Datei nicht gefunden',
'fun_message_1'=>'Du hast das "Zauberwort" vergessen...',
'fun_message_2'=>'Ich denke, daß ich genug von dir habe...',
'fun_message_3'=>'Siehst du nicht, ich bin beschäftigt?',
'fun_message_4'=>'Ich bitte um Entschuldigung?',
'fun_message_5'=>'Nein, das mache ich nicht!',
'fun_message_6'=>'The same procedure as every year, James!',
'fun_message_7'=>'Störe mich jetzt nicht, du *"\$/(=!',
'fun_message_8'=>'*seufz*',
'go_one_step_back'=>'Klicke hier, wenn du einen Schritt zurück möchtest...',
'group'=>'Benutzergruppe',
'group_alias_exec'=>'Verwalter',
'group_alias_guest'=>'Unangemeldet',
'group_alias_mod'=>'Moderator',
'group_alias_root'=>'Super-Benutzer',
'group_alias_user'=>'Mitglied',
'guest'=>'Gast',
'help'=>'Hilfe',
'hidden'=>'Versteckt',
'home'=>'Startseite',
'hour'=>'Stunde',
'hours'=>'Stunden',
'imprint_and_privacy'=>'Impressum und Datenschutzerklärung',
'invalid_form_input'=>'Bitte überprüfe deine Angaben, da einige abgelehnt wurden!',
'javascript_hint'=>'Bitte aktiviere <em>Javascript</em> in deinem Browser, um volle Funktionalität des Forums zu erlangen! Du kannst die Grundfunktionen aber ohne benutzen, sofern du Sicherheitsbedenken hast. Um es zu aktivieren, siehe bitte in der Browserhilfe nach wie man das bewerkstelligt. Üblicherweise ist es unter "Optionen" oder "Einstellungen" zu finden.',
'last_reply'=>'Letzte Antwort',
'login'=>'Anmelden',
'login_valid_for'=>'Verbleibende Anmeldezeit',
'logout'=>'Abmelden',
'mail_address'=>'E-Mail Adresse',
'member_list'=>'Mitgliederliste',
'message'=>'Nachricht',
'minute'=>'Minute',
'minutes'=>'Minuten',
'moderation_panel'=>'Moderation-Konsole',
'month'=>'Monat',
'must_not_alter_foreign_entry'=>'Es ist dir nicht erlaubt fremde Daten zu bearbeiten!',
'my_profile'=>'Mein Profil',
'name'=>'Name',
'new'=>'Neu',
'no'=>'nein',
'none'=>'keine',
'no_members_found'=>'Keine Mitglieder entsprechen deiner Anfrage...',
'no_valid_id'=>'Deine ausgewählte ID ist ungültig!',
'on'=>'am',
'options'=>'Optionen',
'order_by'=>'Sortierung',
'overview'=>'Übersicht',
'page'=>'Seite',
'password'=>'Kennwort',
'pending_requests'=>'Aktuell ausstehende Anfragen',
'please_confirm_reverting'=>'Bitte bestätige, daß du wirklich auf diese Revision rücksetzen möchtest?',
'please_confirm_your_selection'=>'Bitte bestätige, daß du die ausgewählten Objekte unwiederbringlich löschen willst?',
'post_count'=>'Beiträge',
'post_count_hint'=>'Dieser Wert ist ein Schuß ins Blaue und mag von der Wirklichkeit abweichen.',
'prefix_announcement'=>'Ankündigung',
'prefix_executive_only'=>'Nur für Verwalter',
'prefix_moderator_only'=>'Nur für Moderatoren',
'prefix_staff_only'=>'Nur für den Stab',
'prefix_support_request'=>'Benötige Hilfe',
'preview'=>'Vorschau',
'profile_view'=>'Profilansicht',
'query_for'=>'Suche Mitglieder',
'rating'=>'Bewertung',
'really_logout'=>'Möchtest du dich wirklich abmelden?',
'redirection'=>'Weiterleitung',
'register'=>'Registrieren',
'registration_date'=>'Registriert seit',
'replies'=>'Antworten',
'requires_elevated_permissions'=>'Du must in einer Benutzergruppe sein, die erhöhte Rechte besitzt (Verwalter/Moderator), um dies zu tun.',
'running_action_denied_by_acl'=>'Du bist nicht befugt diese Aktion auszuführen, da du von der Zugriffsregel abgewiesen wurdest',
'search'=>'Suche',
'search_posts_by_user'=>'Suche Beiträge',
'second'=>'Sekunde',
'seconds'=>'Sekunden',
'select_color'=>'Farbe auswählen',
'select_user'=>'Benutzer auswählen',
'show_advanced_options'=>'Erweiterte Optionen anzeigen',
'sort_by'=>'Sortiere nach',
'stage'=>'Was tun?',
'standard_panel'=>'Benutzer-Konsole',
'subject'=>'Betreff',
'submit'=>'Absenden',
'success'=>'Erfolgreich',
'tags'=>'Stichwörter',
'to'=>'bis',
'today'=>'Heute',
'total'=>'Total',
'transaction_number_invalid'=>'Du hast nicht die korrekte Transaktionsnummer angegeben!',
'user'=>'Benutzer',
'username'=>'Benutzername',
'user_request'=>'Benutzer-Anfrage',
'visible'=>'Sichtbar',
'warning_high'=>'Du hast unsere Regeln mehrmals verletzt und die höchste Warnstufe erreicht!',
'warning_level'=>'Warnstufe',
'warning_level_high'=>'Hat schon eine Menge Ärger durch Regelverstöße gemacht',
'warning_level_low'=>'Wurde einmalig gewarnt',
'warning_level_medium'=>'Benötigt Aufmerksamkeit auf weiteres Fehlverhalten',
'warning_level_none'=>'Bis jetzt keine Warnung ausgesprochen',
'welcome'=>'Willkommen',
'year'=>'Jahr',
'yes'=>'ja',
'yesterday'=>'Gestern'
);
?>
